@@ -2,4 +2,4 @@
 i18nspector's private modules
 '''
 
-type(...)  # Python >= 3 is required
+int(0_0)  # Python >= 3.6 is required
