@@ -1,4 +1,4 @@
-# Copyright © 2012-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -131,7 +131,7 @@ class Checker(metaclass=abc.ABCMeta):
         elif extension == '.pot':
             constructor = polib.pofile
             is_template = True
-        elif extension in ('.mo', '.gmo'):
+        elif extension in {'.mo', '.gmo'}:
             constructor = polib.mofile
             is_binary = True
         else:
@@ -159,7 +159,7 @@ class Checker(metaclass=abc.ABCMeta):
                     message = message[len(self.path)+1:]
                 match = re.match(r'^\(line ([0-9]+)\)(?:: (.+))?$', message)
                 if match is not None:
-                    lineno_part = 'line {}'.format(match.group(1))
+                    lineno_part = f'line {match.group(1)}'
                     message = match.group(2)
                     if message is not None:
                         lineno_part += ':'
@@ -214,7 +214,7 @@ class Checker(metaclass=abc.ABCMeta):
                 r'<EMAIL@ADDRESS>',
                 r'(?<=>), YEAR\b',
             }
-        regex = re.compile('|'.join(regexs))
+        regex = re.compile(str.join('|', regexs))
         for line in ctx.file.header.splitlines():
             match = regex.search(line)
             if match is None:
@@ -304,8 +304,8 @@ class Checker(metaclass=abc.ABCMeta):
                 self.tag('invalid-language', orig_meta_language)
                 meta_language = None
             if language_source_quality <= 0 and (
-                '/{lang}/'.format(lang=meta_language) in self.path or
-                '/{lang}/'.format(lang=str(meta_language).replace('_', '-')) in self.path
+                f'/{meta_language}/' in self.path or
+                f'/{meta_language}/'.replace('_', '-') in self.path
             ):
                 # For LibreOffice, PO basename does not designate translation
                 # language, but one of the path components does.
@@ -319,7 +319,7 @@ class Checker(metaclass=abc.ABCMeta):
                 language_source = 'Language header field'
             elif language != meta_language:
                 self.tag('language-disparity',
-                    language, tags.safestr('({})'.format(language_source)),
+                    language, tags.safestr(f'({language_source})'),
                     '!=',
                     meta_language, tags.safestr('(Language header field)')
                 )
@@ -344,7 +344,7 @@ class Checker(metaclass=abc.ABCMeta):
                     language_source = 'X-Poedit-Language header field'
                 elif language.language_code != poedit_language.language_code:
                     self.tag('language-disparity',
-                        language, tags.safestr('({})'.format(language_source)),
+                        language, tags.safestr(f'({language_source})'),
                         '!=',
                         poedit_language, tags.safestr('(X-Poedit-Language header field)')
                     )
@@ -395,7 +395,7 @@ class Checker(metaclass=abc.ABCMeta):
             plural_forms_hint = 'nplurals=INTEGER; plural=EXPRESSION;'
         elif correct_plural_forms:
             plural_forms_hint = tags.safe_format(
-                ' or '.join('{}' for s in correct_plural_forms),
+                str.join(' or ', ('{}' for s in correct_plural_forms)),
                 *correct_plural_forms
             )
         else:
@@ -449,7 +449,7 @@ class Checker(metaclass=abc.ABCMeta):
             for i in range(codomain_limit):
                 fi = expr(i)
                 if fi >= n:
-                    message = tags.safe_format('f({}) = {} >= {}'.format(i, fi, n))
+                    message = tags.safe_format(f'f({i}) = {fi} >= {n}')
                     if has_plurals:
                         self.tag('codomain-error-in-plural-forms', message)
                     else:
@@ -498,7 +498,7 @@ class Checker(metaclass=abc.ABCMeta):
                         break
         for rng in uncov_rngs:
             rng = misc.format_range(rng, max=5)
-            message = tags.safestr('f(x) != {}'.format(rng))
+            message = tags.safestr(f'f(x) != {rng}')
             if has_plurals:
                 self.tag('codomain-error-in-plural-forms', message)
             else:
@@ -730,7 +730,7 @@ class Checker(metaclass=abc.ABCMeta):
                 break
             if entry.occurrences:
                 self.tag('empty-msgid-message-with-source-code-references',
-                    *(':'.join((path, line)) for path, line in entry.occurrences)
+                    *(str.join(':', (path, line)) for path, line in entry.occurrences)
                 )
             if entry.msgid_plural is not None:
                 self.tag('empty-msgid-message-with-plural-forms')
@@ -759,10 +759,10 @@ class Checker(metaclass=abc.ABCMeta):
                 self.tag('distant-header-entry')
             unusual_chars = set(find_unusual_characters(msgstr))
             if unusual_chars:
-                unusual_char_names = ', '.join(
-                    'U+{:04X} {}'.format(ord(ch), encinfo.get_character_name(ch))
+                unusual_char_names = str.join(', ', (
+                    f'U+{ord(ch):04X} {encinfo.get_character_name(ch)}'
                     for ch in sorted(unusual_chars)
-                )
+                ))
                 self.tag('unusual-character-in-header-entry', tags.safestr(unusual_char_names))
             seen_header_entry = True
         seen_conflict_marker = False
@@ -856,10 +856,10 @@ class Checker(metaclass=abc.ABCMeta):
                     uc = msgstr_uc - msgid_uc - found_unusual_characters
                     if not uc:
                         continue
-                    names = ', '.join(
-                        'U+{:04X} {}'.format(ord(ch), encinfo.get_character_name(ch))
+                    names = str.join(', ', (
+                        f'U+{ord(ch):04X} {encinfo.get_character_name(ch)}'
                         for ch in sorted(uc)
-                    )
+                    ))
                     self.tag('unusual-character-in-translation',
                         message_repr(message, template='{}:'),
                         tags.safestr(names)
@@ -936,6 +936,13 @@ class Checker(metaclass=abc.ABCMeta):
                         known_flag = True
                         format_flags[tp][string_format] = flag
                         break
+            elif flag == 'markdown-text':
+                # supported by:
+                # * po4a >= 0.58:
+                #   https://github.com/mquinson/po4a/commit/08f93cbe0cc0bcf1
+                # * weblate >= 4.0:
+                #   https://github.com/WeblateOrg/weblate/commit/8832525871c07779
+                pass
             else:
                 known_flag = False
             if not known_flag:
@@ -994,7 +1001,7 @@ class Checker(metaclass=abc.ABCMeta):
             self.tag('redundant-message-flag',
                 message_repr(message, template='{}:'),
                 possible_format_flags[fmt],
-                tags.safe_format('(implied by {flag})'.format(flag=positive_format_flags[fmt]))
+                tags.safe_format(f'(implied by {positive_format_flags[fmt]})')
             )
         return info
 
@@ -1005,7 +1012,7 @@ class Checker(metaclass=abc.ABCMeta):
             except KeyError:
                 continue
             checker.check_message(ctx, message, flags)
-        if re.match(r'\Atype: Content of: (<{xmlname}>)+\Z'.format(xmlname=xml.name_re), message.comment or ''):
+        if re.match(fr'\Atype: Content of: (<{xml.name_re}>)+\Z', message.comment or ''):
             self._check_message_xml_format(ctx, message, flags)
 
     def _check_message_xml_format(self, ctx, message, flags):
