@@ -1,4 +1,4 @@
-# Copyright © 2014-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2014-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -30,7 +30,8 @@ class Checker(metaclass=abc.ABCMeta):
     def __init__(self, parent):
         self.parent = parent
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def backend(self):
         pass
 
@@ -85,7 +86,7 @@ class Checker(metaclass=abc.ABCMeta):
                 msgid_plural_fmt = msgid_fmts.get(1)
                 d.src_loc = 'msgid_plural'
                 d.src_fmt = msgid_plural_fmt
-                d.dst_loc = 'msgstr[{}]'.format(i)
+                d.dst_loc = f'msgstr[{i}]'
                 d.dst_fmt = self.check_string(ctx, message, s)
                 if d.dst_fmt is None:
                     continue
