@@ -1,4 +1,4 @@
-# Copyright © 2013-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2013-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -39,10 +39,8 @@ _regexps = [
     # RFC 6762, §3 <https://tools.ietf.org/html/rfc6762#section-3>:
     '(.+[.])local',
 ]
-
-_is_special = re.compile(
-    '^({re})$'.format(re='|'.join(_regexps))
-).match
+_regexps = str.join('|', _regexps)
+_is_special = re.compile(f'^({_regexps})$').match
 
 def is_special_domain(domain):
     domain = domain.lower()
