@@ -1,4 +1,4 @@
-# Copyright © 2012-2020 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -55,7 +55,7 @@ def charmap_encoding(encoding):
 
     path = os.path.join(paths.datadir, 'charmaps', encoding.upper())
     try:
-        file = open(path, 'rb')
+        file = open(path, 'rb')  # pylint: disable=consider-using-with
     except FileNotFoundError:
         raise EncodingLookupError(encoding)
     with file:
