@@ -1,4 +1,4 @@
-# Copyright © 2012-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -135,7 +135,7 @@ def _read_timezones():
 
 _timezones = _read_timezones()
 
-_tz_re = '|'.join(re.escape(tz) for tz in _timezones)
+_tz_re = str.join('|', (re.escape(tz) for tz in _timezones))
 _parse_date = re.compile(r'''
     ^
     ( [0-9]{4}-[0-9]{2}-[0-9]{2} )  # YYYY-MM-DD
@@ -182,8 +182,8 @@ def fix_date_format(s, *, tz_hint=None):
         zone = tz_hint
     else:
         raise DateSyntaxError
-    s = '{} {}{}'.format(date, time, zone)
-    assert len(s) == 21, 'len({!r}) != 21'.format(s)
+    s = f'{date} {time}{zone}'
+    assert len(s) == 21, f'len({s!r}) != 21'
     parse_date(s)  # just check syntax
     return s
 
