@@ -1,4 +1,4 @@
-# Copyright © 2012-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -32,7 +32,7 @@ from lib import paths
 
 def _munch_language_name(s):
     # Normalize whitespace:
-    s = ' '.join(s.split())
+    s = str.join(' ', s.split())
     # Normalize capitalization:
     s = s.lower()
     # Strip accent marks etc.:
@@ -166,7 +166,7 @@ class Language():
             # If iconv(1) is used to implement an encoding, there's a huge
             # overhead per encode() call. To reduce number of such calls,
             # optimize the common case of all characters being representable.
-            ''.join(characters).encode(encoding)
+            str.join('', characters).encode(encoding)
         except UnicodeEncodeError:
             pass
         else:
@@ -198,7 +198,7 @@ class Language():
         return s
 
     def __repr__(self):
-        return '<Language {}>'.format(self)
+        return f'<Language {self}>'
 
 def _read_iso_codes():
     # ISO language/territory codes:
@@ -237,7 +237,7 @@ def _read_primary_languages():
                 continue
             if key.startswith('characters@'):
                 continue
-            raise misc.DataIntegrityError('unknown key: {}'.format(key))
+            raise misc.DataIntegrityError(f'unknown key: {key}')
         for name in section['names'].splitlines():
             name = _munch_language_name(name)
             if name:
@@ -281,7 +281,7 @@ def get_language_for_name(name):
             except LookupError:
                 pass
     if ',' in _name:
-        subname = ' '.join(map(str.strip, _name.split(',', 1)[::-1]))
+        subname = str.join(' ', map(str.strip, _name.split(',', 1)[::-1]))
         try:
             return parse(_name_to_code[subname])
         except LookupError:
@@ -340,7 +340,7 @@ def _get_characters(language, modifier=None, strict=True):
         return
     section_name = 'characters'
     if modifier is not None:
-        section_name += '@{}'.format(modifier)
+        section_name += f'@{modifier}'
     result = section.get(section_name)
     if result is None:
         return
