@@ -1,4 +1,4 @@
-# Copyright © 2013-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2013-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -90,7 +90,7 @@ class Parser():
         [revision] = self._read_ints(at=4)
         major_revision, minor_revision = divmod(revision, 1 << 16)
         if major_revision > 1:
-            raise SyntaxError('unexpected major revision number: {n}'.format(n=major_revision))
+            raise SyntaxError(f'unexpected major revision number: {major_revision}')
         [n_strings] = self._read_ints(at=8)
         possible_hidden_strings = False
         if minor_revision > 1:
@@ -182,7 +182,7 @@ __all__ = ['Parser', 'SyntaxError']
 def main():
     import argparse  # pylint: disable=import-outside-toplevel
     ap = argparse.ArgumentParser(description='msgunfmt(1) replacement')
-    ap.add_argument('files', metavar='<file>', nargs='+')
+    ap.add_argument('files', metavar='FILE', nargs='+')
     options = ap.parse_args()
     for path in options.files:
         escaped_path = ascii(path)[1:-1]
