@@ -1,4 +1,4 @@
-# Copyright © 2012-2019 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -24,7 +24,6 @@ polib monkey-patching
 
 import ast
 import codecs
-import contextlib
 import inspect
 import re
 
@@ -44,7 +43,7 @@ def install_patches():
 __all__ = ['install_patches']
 
 def register_patch(patch):
-    patches.append(contextlib.contextmanager(patch))
+    patches.append(patch)
 
 # polib.default_encoding
 # ======================
@@ -87,8 +86,7 @@ class Codecs():
             if line[:2] in {'', '# '} or line.isspace():
                 pending_comments += [line]
             else:
-                for comment_line in pending_comments:
-                    yield comment_line
+                yield from pending_comments
                 pending_comments = []
                 yield line
                 empty = False
@@ -133,7 +131,7 @@ def polib_unescape(s):
     def unescape(match):
         s = match.group()
         s = _short_x_escape_re.sub(r'\\x0\1', s)
-        result = ast.literal_eval("b'{}'".format(s))
+        result = ast.literal_eval(f"b'{s}'")
         try:
             return result.decode('ASCII')  # pylint: disable=no-member
         except UnicodeDecodeError:
