@@ -1,4 +1,4 @@
-# Copyright © 2014-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2014-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -77,11 +77,11 @@ class _info:
     t = ptrdiff_t | [unsigned ptrdiff_t]
     = int | unsigned int
     '''
-    int_types = dict(
-        (key, tuple(str.strip(v) for v in values.split('|')))
+    int_types = {
+        key: tuple(str.strip(v) for v in values.split('|'))
         for line in int_types.strip().splitlines()
         for key, values in [map(str.strip, line.split('='))]
-    )
+    }
     # FIXME: The printf(3) manpage says that the type for signed integer with
     # “z“ size is ssize_t.
     # But SUSv3 says it's a signed integer type corresponding to size_t,
@@ -90,8 +90,6 @@ class _info:
     # https://www.gnu.org/software/libc/manual/html_node/Integer-Conversions.html
     portable_int_lengths = dict(
         L='ll',
-        # The use of “L” with integer conversions is not documented
-        # in the printf(3) manpage. https://bugs.debian.org/757151
         q='ll',
         Z='z',
     )
@@ -254,7 +252,7 @@ class FormatString():
                     if conv is not arg:
                         return
                 else:
-                    assert False, 'type(arg) == {!r}'.format(type(arg))  # no coverage
+                    assert False, f'type(arg) == {type(arg)!r}'  # no coverage
         if conv is None:
             return
         if not conv.integer:
@@ -403,7 +401,7 @@ class Conversion():
             except IndexError:
                 raise ArgumentNumberingMixture(s)
             except OverflowError as exc:
-                raise ArgumentRangeError(s, '{}$'.format(exc))
+                raise ArgumentRangeError(s, f'{exc}$')
             width = ...
         if width is not None:
             if conversion in '%n':
@@ -428,7 +426,7 @@ class Conversion():
             except IndexError:
                 raise ArgumentNumberingMixture(s)
             except OverflowError as exc:
-                raise ArgumentRangeError(s, '{}$'.format(exc))
+                raise ArgumentRangeError(s, f'{exc}$')
             precision = ...
         if precision is not None:
             if conversion in i.int_cvt + i.float_cvt + i.str_cvt:
@@ -464,6 +462,6 @@ class Conversion():
             except IndexError:
                 raise ArgumentNumberingMixture(s)
             except OverflowError as exc:
-                raise ArgumentRangeError(s, '{}$'.format(exc))
+                raise ArgumentRangeError(s, f'{exc}$')
 
 # vim:ts=4 sts=4 sw=4 et
