@@ -1,4 +1,4 @@
-# Copyright © 2015-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -236,7 +236,7 @@ class FormatString():
 class Conversion():
 
     def __init__(self, parent, s, *, key, flags, width, var_width, prec, var_prec, length, conv):
-        assert s[-1] == conv, '{0} != {1}'.format(s[-1], conv)
+        assert s[-1] == conv, f'{s[-1]} != {conv}'
         i = _info
         for flag, count in flags.items():
             if count != 1:
