@@ -1,4 +1,4 @@
-# Copyright © 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2014-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -30,7 +30,7 @@ SyntaxError = xml.parsers.expat.ExpatError  # pylint: disable=redefined-builtin
 
 _xe = (
     'i18nspector.' +
-    ''.join(random.choice(string.ascii_lowercase) for x in range(12))
+    str.join('', (random.choice(string.ascii_lowercase) for x in range(12)))
 )
 
 _source = '''\
@@ -59,6 +59,6 @@ def check_fragment(s):
 # pylint: disable=line-too-long
 _start_char = ':A-Z_a-z\xC0-\xD6\xD8-\xF6\xF8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\U00010000-\U000EFFFF'
 _next_char = _start_char + '.0-9\xB7\u0300-\u036F\u203F\u2040-'
-name_re = '[{0}][{1}]*'.format(_start_char, _next_char)
+name_re = f'[{_start_char}][{_next_char}]*'
 
 # vim:ts=4 sts=4 sw=4 et
