@@ -1,4 +1,4 @@
-# Copyright © 2012-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -31,9 +31,6 @@ import sys
 import traceback
 import unittest
 
-import nose
-import nose.plugins
-
 from .. import tools
 
 here = os.path.dirname(__file__)
@@ -79,20 +76,16 @@ def tagstring(s):
 class ETag():
 
     _ellipsis = '<...>'
-    _split = re.compile('({})'.format(re.escape(_ellipsis))).split
+    _split = re.compile(f'({re.escape(_ellipsis)})').split
 
     def __init__(self, code, path, rest):
-        self._s = s = '{code}: {path}: {rest}'.format(
-            code=code,
-            path=path,
-            rest=rest,
-        )
+        self._s = s = f'{code}: {path}: {rest}'
         self.tag = rest.split(None, 1)[0]
-        regexp = ''.join(
+        regexp = str.join('', (
             '.*' if chunk == self._ellipsis else re.escape(chunk)
             for chunk in self._split(s)
-        )
-        self._regexp = re.compile('^{}$'.format(regexp))
+        ))
+        self._regexp = re.compile(f'^{regexp}$')
 
     def __eq__(self, other):
         if isinstance(other, str):
@@ -109,11 +102,11 @@ class ETag():
 # ----------------------------------------
 
 def _get_signal_names():
-    data = dict(
-        (name, getattr(signal, name))
+    data = {
+        name: getattr(signal, name)
         for name in dir(signal)
         if re.compile('^SIG[A-Z0-9]*$').match(name)
-    )
+    }
     try:
         if data['SIGABRT'] == data['SIGIOT']:
             del data['SIGIOT']
@@ -140,26 +133,32 @@ def get_signal_name(n):
 test_file_extensions = ('.mo', '.po', '.pot', '.pop')
 # .pop is a special extension to trigger unknown-file-type
 
-class Plugin(nose.plugins.Plugin):
+def nose_plugin():
 
-    name = 'po-plugin'
-    enabled = True
+    import nose.plugins  # pylint: disable=import-outside-toplevel
 
-    def options(self, parser, env):
-        pass
+    class Plugin(nose.plugins.Plugin):
 
-    def wantFile(self, path):
-        if path.endswith(test_file_extensions):
-            if path.startswith(os.path.join(os.path.abspath(here), '')):
-                return True
+        name = 'po-plugin'
+        enabled = True
 
-    def loadTestsFromFile(self, path):
-        if self.wantFile(path):
-            yield TestCase(path)
+        def options(self, parser, env):
+            pass
 
-    def wantFunction(self, func):
-        if getattr(func, 'redundant', False):
-            return False
+        def wantFile(self, path):
+            if path.endswith(test_file_extensions):
+                if path.startswith(os.path.join(os.path.abspath(here), '')):
+                    return True
+
+        def loadTestsFromFile(self, path):
+            if self.wantFile(path):
+                yield TestCase(path)
+
+        def wantFunction(self, func):
+            if getattr(func, 'redundant', False):
+                return False
+
+    return Plugin()
 
 class TestCase(unittest.TestCase):
 
@@ -219,19 +218,19 @@ def run_i18nspector(options, path):
         commandline += options
         commandline += [path]
         fixed_env = dict(os.environ, PYTHONIOENCODING='UTF-8')
-        child = ipc.Popen(commandline, stdout=ipc.PIPE, stderr=ipc.PIPE, env=fixed_env)
-        stdout, stderr = (
-            s.decode('UTF-8').splitlines()
-            for s in child.communicate()
-        )
+        with ipc.Popen(commandline, stdout=ipc.PIPE, stderr=ipc.PIPE, env=fixed_env) as child:
+            stdout, stderr = (
+                s.decode('UTF-8').splitlines()
+                for s in child.communicate()
+            )
         rc = child.poll()
     assert isinstance(rc, int)
     if rc == 0:
         return stdout
     if rc < 0:
-        message = ['command was interrupted by signal {sig}'.format(sig=get_signal_name(-rc))]  # pylint: disable=invalid-unary-operand-type
+        message = [f'command was interrupted by signal {get_signal_name(-rc)}']  # pylint: disable=invalid-unary-operand-type
     else:
-        message = ['command exited with status {rc}'.format(rc=rc)]
+        message = [f'command exited with status {rc}']
     message += ['']
     if stdout:
         message += ['stdout:']
@@ -243,7 +242,7 @@ def run_i18nspector(options, path):
         message += ['| ' + s for s in stderr]
     else:
         message += ['stderr: (empty)']
-    raise SubprocessError('\n'.join(message))
+    raise SubprocessError(str.join('\n', message))
 
 def _mp_run_i18nspector(prog, options, path, queue):
     with open(prog, 'rt', encoding='UTF-8') as file:
@@ -258,6 +257,7 @@ def _mp_run_i18nspector(prog, options, path, queue):
         __file__=prog,
     )
     (sys.stdout, sys.stderr) = (io_stdout, io_stderr)
+    stdout = stderr = ''
     try:
         try:
             exec(code, gvars)  # pylint: disable=exec-used
@@ -270,7 +270,7 @@ def _mp_run_i18nspector(prog, options, path, queue):
         raise
     except:  # pylint: disable=bare-except
         exctp, exc, tb = sys.exc_info()
-        stderr += ''.join(
+        stderr += str.join('',
             traceback.format_exception(exctp, exc, tb)
         )
         queue.put([stdout, stderr])
@@ -286,14 +286,14 @@ def assert_emit_tags(path, etags, *, options=()):
     expected_failure = os.path.basename(path).startswith('xfail-')
     if stdout != etags:
         if expected_failure:
-            raise nose.SkipTest('expected failure')
+            raise unittest.SkipTest('expected failure')
         str_etags = [str(x) for x in etags]
         message = ['Tags differ:', '']
         diff = list(
             difflib.unified_diff(str_etags, stdout, n=9999)
         )
         message += diff[3:]
-        raise AssertionError('\n'.join(message))
+        raise AssertionError(str.join('\n', message))
     elif expected_failure:
         raise AssertionError('unexpected success')
 
@@ -327,7 +327,7 @@ def _parse_test_header_file(file, path, *, comments_only):
 def _parse_test_headers(path):
     # <path>.tags:
     try:
-        file = open(path + '.tags', encoding='UTF-8')
+        file = open(path + '.tags', encoding='UTF-8')  # pylint: disable=consider-using-with
     except FileNotFoundError:
         pass
     else:
@@ -335,7 +335,7 @@ def _parse_test_headers(path):
             return _parse_test_header_file(file, path, comments_only=False)
     # <path>.gen:
     try:
-        file = open(path + '.gen', encoding='UTF-8', errors='ignore')
+        file = open(path + '.gen', encoding='UTF-8', errors='ignore')  # pylint: disable=consider-using-with
     except FileNotFoundError:
         pass
     else:
@@ -369,6 +369,7 @@ def _get_test_filenames():
                 continue
             yield os.path.join(root, filename)
 
+@tools.collect_yielded
 def test_file():
     for filename in _get_test_filenames():
         path = os.path.relpath(filename, start=here)
@@ -389,7 +390,7 @@ E: os-error Permission denied
 ''')
 def test_os_error_permission_denied():
     if os.getuid() == 0:
-        raise nose.SkipTest('this test must not be run as root')
+        raise unittest.SkipTest('this test must not be run as root')
     with tools.temporary_directory() as tmpdir:
         path = os.path.join(tmpdir, 'denied.po')
         with open(path, 'wb'):
