@@ -1,4 +1,4 @@
-# Copyright © 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2014-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -21,12 +21,13 @@
 import os
 import re
 
-from nose.tools import (
-    assert_not_equal,
-)
-
 import lib.tags
 
+from .tools import (
+    assert_not_equal,
+    collect_yielded,
+)
+
 here = os.path.dirname(__file__)
 docdir = os.path.join(here, os.pardir, 'doc')
 
@@ -52,6 +53,7 @@ rename_re = re.compile(
     r'([\w-]+) [(]from ([\w-]+)[)]'
 )
 
+@collect_yielded
 def test_tags():
     path = os.path.join(docdir, 'changelog')
     with open(path, 'rt', encoding='UTF-8') as file:
@@ -108,6 +110,6 @@ def test_trailing_whitespace():
                 continue
             line = line.rstrip('\n')
             if line[-1:].isspace():
-                raise AssertionError('trailing whitespace at line {0}'.format(n))
+                raise AssertionError(f'trailing whitespace at line {n}')
 
 # vim:ts=4 sts=4 sw=4 et
