@@ -1,4 +1,4 @@
-# Copyright © 2012-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -20,21 +20,22 @@
 
 import curses.ascii
 import sys
+import unittest
 
-import nose
-from nose.tools import (
+import lib.encodings as E
+
+from . import tools
+
+from .tools import (
     assert_equal,
     assert_false,
     assert_is_none,
     assert_not_in,
     assert_raises,
     assert_true,
+    collect_yielded,
 )
 
-import lib.encodings as E
-
-from . import tools
-
 class test_is_portable_encoding:
 
     def test_found(self):
@@ -58,6 +59,7 @@ class test_propose_portable_encoding:
         portable_encoding = E.propose_portable_encoding(encoding)
         assert_equal(portable_encoding, encoding)
 
+    @collect_yielded
     def test_found(self):
         def t(encoding, expected_portable_encoding):
             portable_encoding = E.propose_portable_encoding(encoding)
@@ -72,6 +74,7 @@ class test_propose_portable_encoding:
 
 class test_ascii_compatibility:
 
+    @collect_yielded
     def test_portable(self):
         def t(encoding):
             assert_true(E.is_ascii_compatible_encoding(encoding))
@@ -79,6 +82,7 @@ class test_ascii_compatibility:
         for encoding in E.get_portable_encodings():
             yield t, encoding
 
+    @collect_yielded
     def test_incompatible(self):
         def t(encoding):
             assert_false(E.is_ascii_compatible_encoding(encoding))
@@ -91,6 +95,7 @@ class test_ascii_compatibility:
         with assert_raises(E.EncodingLookupError):
             E.is_ascii_compatible_encoding(encoding, missing_ok=False)
 
+    @collect_yielded
     def test_non_text(self):
         t = self._test_missing
         yield t, 'base64_codec'
@@ -164,7 +169,7 @@ class test_extra_encoding:
         except LookupError:
             pass
         else:
-            raise nose.SkipTest(
+            raise unittest.SkipTest(
                 'python{ver[0]}.{ver[1]} supports the {enc} encoding'.format(
                     ver=sys.version_info,
                     enc=encoding
@@ -193,7 +198,7 @@ class test_extra_encoding:
         except LookupError:
             pass
         else:
-            raise nose.SkipTest(
+            raise unittest.SkipTest(
                 'python{ver[0]}.{ver[1]} supports the {enc} encoding'.format(
                     ver=sys.version_info,
                     enc=encoding
