@@ -1,4 +1,4 @@
-# Copyright © 2013-2019 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2013-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -18,13 +18,13 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from nose.tools import (
+import lib.iconv as M
+
+from .tools import (
     assert_equal,
     assert_raises,
 )
 
-import lib.iconv as M
-
 class _test:
     u = None
     b = None
