@@ -1,4 +1,4 @@
-# Copyright © 2012-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -18,8 +18,14 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-import nose
-from nose.tools import (
+import unittest
+
+import lib.encodings
+import lib.ling
+
+from . import tools
+
+from .tools import (
     assert_equal,
     assert_false,
     assert_in,
@@ -30,13 +36,9 @@ from nose.tools import (
     assert_not_in,
     assert_raises,
     assert_true,
+    collect_yielded,
 )
 
-import lib.encodings
-import lib.ling
-
-from . import tools
-
 L = lib.ling
 T = lib.ling.Language
 E = lib.encodings
@@ -252,6 +254,7 @@ class test_get_primary_languages:
         langs = L.get_primary_languages()
         assert_not_in('ry', langs)
 
+    @collect_yielded
     def test_iso_639(self):
         def t(lang_str):
             lang = L.parse_language(lang_str)
@@ -343,7 +346,7 @@ class test_principal_territory:
     def test_not_found(self):
         lang = L.parse_language('ry')
         cc = lang.get_principal_territory_code()
-        assert_equal(cc, None)
+        assert_is_none(cc)
 
 class test_unrepresentable_characters:
 
@@ -411,6 +414,7 @@ class test_unrepresentable_characters:
         result = lang.get_unrepresentable_characters(encoding)
         assert_not_equal(result, [])
 
+@collect_yielded
 def test_glibc_supported():
     def t(l):
         lang = L.parse_language(l)
@@ -419,16 +423,16 @@ def test_glibc_supported():
         except L.FixingLanguageCodesFailed:
             # FIXME: some ISO-639-3 codes are not recognized yet
             if len(l.split('_')[0]) == 3:
-                raise nose.SkipTest('expected failure')
+                raise unittest.SkipTest('expected failure')
             reason = locales_to_skip.get(l)
             if reason is not None:
-                raise nose.SkipTest(reason)
+                raise unittest.SkipTest(reason)
             raise
         assert_equal(str(lang), l)
     try:
-        file = open('/usr/share/i18n/SUPPORTED', encoding='ASCII')
+        file = open('/usr/share/i18n/SUPPORTED', encoding='ASCII')  # pylint: disable=consider-using-with
     except OSError as exc:
-        raise nose.SkipTest(exc)
+        raise unittest.SkipTest(exc)
     locales = set()
     with file:
         for line in file:
@@ -439,6 +443,8 @@ def test_glibc_supported():
             if (locale + '.').startswith('iw_IL.'):
                 # iw_IL is obsolete
                 continue
+            if locale.startswith('C.'):
+                continue
             locales.add(locale)
     misnamed_locales = {
         # glibc 2.21 had two misnamed locales:
@@ -452,6 +458,7 @@ def test_glibc_supported():
     for l in sorted(locales):
         yield t, l
 
+@collect_yielded
 def test_poedit():
     # https://github.com/vslavik/poedit/blob/v1.8.1-oss/src/language_impl_legacy.h
     # There won't be any new names in this table,
@@ -464,7 +471,7 @@ def test_poedit():
         poedit_ll = L.parse_language(poedit_ll)
         with assert_raises(LookupError):
             L.get_language_for_name(name)
-        raise nose.SkipTest('expected failure')
+        raise unittest.SkipTest('expected failure')
     yield t, 'Abkhazian', 'ab'
     yield t, 'Afar', 'aa'
     yield t, 'Afrikaans', 'af'
