@@ -1,4 +1,4 @@
-# Copyright © 2012-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -24,7 +24,9 @@ import stat
 import tempfile
 import time
 
-from nose.tools import (
+import lib.misc as M
+
+from .tools import (
     assert_almost_equal,
     assert_equal,
     assert_is_instance,
@@ -33,8 +35,6 @@ from nose.tools import (
     assert_true,
 )
 
-import lib.misc as M
-
 from . import tools
 
 class test_unsorted:
