@@ -1,4 +1,4 @@
-# Copyright © 2013-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2013-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -20,13 +20,13 @@
 
 import polib
 
-from nose.tools import (
+import lib.polib4us as M
+
+from .tools import (
     assert_list_equal,
     assert_true,
 )
 
-import lib.polib4us as M
-
 from . import tools
 
 minimal_header = r'''
