@@ -1,4 +1,4 @@
-# Copyright © 2014-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2014-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -23,17 +23,17 @@ import struct
 import sys
 import unittest.mock
 
-import nose
-from nose.tools import (
+import lib.strformat.c as M
+
+from .tools import (
     assert_equal,
     assert_greater,
     assert_is_instance,
     assert_raises,
     assert_sequence_equal,
+    collect_yielded,
 )
 
-import lib.strformat.c as M
-
 def test_INT_MAX():
     struct.pack('=i', M.INT_MAX)
     with assert_raises(struct.error):
@@ -54,7 +54,7 @@ def test_NL_ARGMAX():
             os.sysconf('SC_NL_ARGMAX')
         )
     else:
-        raise nose.SkipTest('Test specific to Linux with glibc')
+        raise unittest.SkipTest('Test specific to Linux with glibc')
 
 small_NL_ARGMAX = unittest.mock.patch('lib.strformat.c.NL_ARGMAX', 42)
 # Setting NL_ARGMAX to a small number makes the *_index_out_of_range() tests
@@ -100,39 +100,41 @@ class test_types:
             assert_is_instance(warning, warn_type)
         assert_equal(conv.integer, integer)
 
+    @collect_yielded
     def test_integer(self):
         def t(s, tp, warn_type=None):
-            integer = not suffix
-            self.t(s, tp + suffix, warn_type, integer)
+            if s[-1] == 'n':
+                tp += ' *'
+                integer = False
+            else:
+                integer = True
+            return (self.t, s, tp, warn_type, integer)
         for c in 'din':
-            suffix = ''
-            if c == 'n':
-                suffix = ' *'
-            yield t, ('%hh' + c), 'signed char'
-            yield t, ('%h' + c), 'short int'
-            yield t, ('%' + c), 'int'
-            yield t, ('%l' + c), 'long int'
-            yield t, ('%ll' + c), 'long long int'
-            yield t, ('%L' + c), 'long long int', M.NonPortableConversion
-            yield t, ('%q' + c), 'long long int', M.NonPortableConversion
-            yield t, ('%j' + c), 'intmax_t'
-            yield t, ('%z' + c), 'ssize_t'
-            yield t, ('%Z' + c), 'ssize_t', M.NonPortableConversion
-            yield t, ('%t' + c), 'ptrdiff_t'
+            yield t('%hh' + c, 'signed char')
+            yield t('%h' + c, 'short int')
+            yield t('%' + c, 'int')
+            yield t('%l' + c, 'long int')
+            yield t('%ll' + c, 'long long int')
+            yield t('%L' + c, 'long long int', M.NonPortableConversion)
+            yield t('%q' + c, 'long long int', M.NonPortableConversion)
+            yield t('%j' + c, 'intmax_t')
+            yield t('%z' + c, 'ssize_t')
+            yield t('%Z' + c, 'ssize_t', M.NonPortableConversion)
+            yield t('%t' + c, 'ptrdiff_t')
         for c in 'ouxX':
-            suffix = ''
-            yield t, ('%hh' + c), 'unsigned char'
-            yield t, ('%h' + c), 'unsigned short int'
-            yield t, ('%' + c), 'unsigned int'
-            yield t, ('%l' + c), 'unsigned long int'
-            yield t, ('%ll' + c), 'unsigned long long int'
-            yield t, ('%L' + c), 'unsigned long long int', M.NonPortableConversion
-            yield t, ('%q' + c), 'unsigned long long int', M.NonPortableConversion
-            yield t, ('%j' + c), 'uintmax_t'
-            yield t, ('%z' + c), 'size_t'
-            yield t, ('%Z' + c), 'size_t', M.NonPortableConversion
-            yield t, ('%t' + c), '[unsigned ptrdiff_t]'
+            yield t('%hh' + c, 'unsigned char')
+            yield t('%h' + c, 'unsigned short int')
+            yield t('%' + c, 'unsigned int')
+            yield t('%l' + c, 'unsigned long int')
+            yield t('%ll' + c, 'unsigned long long int')
+            yield t('%L' + c, 'unsigned long long int', M.NonPortableConversion)
+            yield t('%q' + c, 'unsigned long long int', M.NonPortableConversion)
+            yield t('%j' + c, 'uintmax_t')
+            yield t('%z' + c, 'size_t')
+            yield t('%Z' + c, 'size_t', M.NonPortableConversion)
+            yield t('%t' + c, '[unsigned ptrdiff_t]')
 
+    @collect_yielded
     def test_double(self):
         t = self.t
         for c in 'aefgAEFG':
@@ -140,6 +142,7 @@ class test_types:
             yield t, ('%l' + c), 'double', M.NonPortableConversion
             yield t, ('%L' + c), 'long double'
 
+    @collect_yielded
     def test_char(self):
         t = self.t
         yield t, '%c', 'char'
@@ -149,12 +152,14 @@ class test_types:
         yield t, '%ls', 'const wchar_t *'
         yield t, '%S', 'const wchar_t *', M.NonPortableConversion
 
+    @collect_yielded
     def test_void(self):
         t = self.t
         yield t, '%p', 'void *'
         yield t, '%m', 'void'
         yield t, '%%', 'void'
 
+    @collect_yielded
     def test_c99_macros(self):
         # pylint: disable=undefined-loop-variable
         def _t(s, tp):
@@ -162,7 +167,7 @@ class test_types:
         def t(s, tp):
             return (
                 _t,
-                '%<{macro}>'.format(macro=s.format(c=c, n=n)),
+                f'%<{s.format(c=c, n=n)}>',
                 ('u' if unsigned else '') + tp.format(n=n)
             )
         # pylint: enable=undefined-loop-variable
@@ -182,6 +187,7 @@ class test_invalid_length:
 
     _lengths = ['hh', 'h', 'l', 'll', 'q', 'j', 'z', 't', 'L']
 
+    @collect_yielded
     def test_double(self):
         t = self.t
         for c in 'aefgAEFG':
@@ -190,6 +196,7 @@ class test_invalid_length:
                     continue
                 yield t, ('%' + l + c)
 
+    @collect_yielded
     def test_char(self):
         t = self.t
         for c in 'cs':
@@ -198,6 +205,7 @@ class test_invalid_length:
                     yield t, '%' + l + c
                 yield t, ('%' + l + c.upper())
 
+    @collect_yielded
     def test_void(self):
         t = self.t
         for c in 'pm%':
@@ -235,10 +243,10 @@ class test_numeration:
         with assert_raises(M.ArgumentRangeError):
             M.FormatString('%0$d')
         def fs(n):
-            s = ''.join(
-                '%{0}$d'.format(i)
+            s = str.join('', (
+                f'%{i}$d'
                 for i in range(1, n + 1)
-            )
+            ))
             return M.FormatString(s)
         fmt = fs(M.NL_ARGMAX)
         assert_equal(len(fmt), M.NL_ARGMAX)
@@ -278,18 +286,22 @@ class test_expected_flag:
         fmt = M.FormatString(s)
         assert_equal(len(fmt), 1)
 
+    @collect_yielded
     def test_hash(self):
         for c in 'oxXaAeEfFgG':
             yield self.t, ('%#' + c)
 
+    @collect_yielded
     def test_zero(self):
         for c in 'diouxXaAeEfFgG':
             yield self.t, ('%0' + c)
 
+    @collect_yielded
     def test_apos(self):
         for c in 'diufFgG':
             yield self.t, ("%'" + c)
 
+    @collect_yielded
     def test_other(self):
         for flag in '- +I':
             for c in 'diouxXaAeEfFgGcCsSpm':
@@ -301,18 +313,22 @@ class test_unexpected_flag:
         with assert_raises(M.FlagError):
             M.FormatString(s)
 
+    @collect_yielded
     def test_hash(self):
         for c in 'dicCsSnpm%':
             yield self.t, ('%#' + c)
 
+    @collect_yielded
     def test_zero(self):
         for c in 'cCsSnpm%':
             yield self.t, ('%0' + c)
 
+    @collect_yielded
     def test_apos(self):
         for c in 'oxXaAeEcCsSnpm%':
             yield self.t, ("%'" + c)
 
+    @collect_yielded
     def test_other(self):
         for c in '%n':
             for flag in '- +I':
@@ -320,6 +336,7 @@ class test_unexpected_flag:
 
 class test_width:
 
+    @collect_yielded
     def test_ok(self):
         def t(s):
             fmt = M.FormatString(s)
@@ -334,11 +351,11 @@ class test_width:
                 M.FormatString('%1' + c)
 
     def test_too_large(self):
-        fmt = M.FormatString('%{0}d'.format(M.INT_MAX))
+        fmt = M.FormatString(f'%{M.INT_MAX}d')
         assert_equal(len(fmt), 1)
         assert_equal(len(fmt.arguments), 1)
         with assert_raises(M.WidthRangeError):
-            M.FormatString('%{0}d'.format(M.INT_MAX + 1))
+            M.FormatString(f'%{M.INT_MAX + 1}d')
 
     def test_variable(self):
         fmt = M.FormatString('%*s')
@@ -349,7 +366,7 @@ class test_width:
         assert_equal(a2.type, 'const char *')
 
     def _test_index(self, i):
-        fmt = M.FormatString('%2$*{0}$s'.format(i))
+        fmt = M.FormatString(f'%2$*{i}$s')
         assert_equal(len(fmt), 1)
         assert_equal(len(fmt.arguments), 2)
         [a1], [a2] = fmt.arguments
@@ -368,10 +385,10 @@ class test_width:
         with assert_raises(M.ArgumentRangeError):
             M.FormatString('%1$*0$s')
         def fs(n):
-            s = ''.join(
-                '%{0}$d'.format(i)
+            s = str.join('', (
+                f'%{i}$d'
                 for i in range(2, n)
-            ) + '%1$*{0}$s'.format(n)
+            )) + f'%1$*{n}$s'
             return M.FormatString(s)
         fmt = fs(M.NL_ARGMAX)
         assert_equal(len(fmt), M.NL_ARGMAX - 1)
@@ -390,6 +407,7 @@ class test_width:
 
 class test_precision:
 
+    @collect_yielded
     def test_ok(self):
         def t(s):
             fmt = M.FormatString(s)
@@ -397,6 +415,7 @@ class test_precision:
         for c in 'diouxXaAeEfFgGsS':
             yield t, ('%.1' + c)
 
+    @collect_yielded
     def test_redundant_0(self):
         def t(s):
             fmt = M.FormatString(s)
@@ -406,6 +425,7 @@ class test_precision:
         for c in 'diouxX':
             yield t, ('%0.1' + c)
 
+    @collect_yielded
     def test_non_redundant_0(self):
         def t(s):
             fmt = M.FormatString(s)
@@ -414,6 +434,7 @@ class test_precision:
         for c in 'aAeEfFgG':
             yield t, ('%0.1' + c)
 
+    @collect_yielded
     def test_unexpected(self):
         def t(s):
             with assert_raises(M.PrecisionError):
@@ -422,10 +443,10 @@ class test_precision:
             yield t, ('%.1' + c)
 
     def test_too_large(self):
-        fmt = M.FormatString('%.{0}f'.format(M.INT_MAX))
+        fmt = M.FormatString(f'%.{M.INT_MAX}f')
         assert_equal(len(fmt), 1)
         with assert_raises(M.PrecisionRangeError):
-            M.FormatString('%.{0}f'.format(M.INT_MAX + 1))
+            M.FormatString(f'%.{M.INT_MAX + 1}f')
 
     def test_variable(self):
         fmt = M.FormatString('%.*f')
@@ -436,7 +457,7 @@ class test_precision:
         assert_equal(a2.type, 'double')
 
     def _test_index(self, i):
-        fmt = M.FormatString('%2$.*{0}$f'.format(i))
+        fmt = M.FormatString(f'%2$.*{i}$f')
         assert_equal(len(fmt), 1)
         assert_equal(len(fmt.arguments), 2)
         [a1], [a2] = fmt.arguments
@@ -455,10 +476,10 @@ class test_precision:
         with assert_raises(M.ArgumentRangeError):
             M.FormatString('%1$.*0$f')
         def fs(n):
-            s = ''.join(
-                '%{0}$d'.format(i)
+            s = str.join('', (
+                f'%{i}$d'
                 for i in range(2, n)
-            ) + '%1$.*{0}$f'.format(n)
+            )) + f'%1$.*{n}$f'
             return M.FormatString(s)
         fmt = fs(M.NL_ARGMAX)
         assert_equal(len(fmt), M.NL_ARGMAX - 1)
