@@ -1,4 +1,4 @@
-# Copyright © 2012-2019 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -24,17 +24,18 @@ import inspect
 import operator
 import pkgutil
 
-from nose.tools import (
+import lib.check
+import lib.tags as M
+
+from .tools import (
     assert_equal,
     assert_false,
     assert_is_instance,
     assert_raises,
     assert_true,
+    collect_yielded,
 )
 
-import lib.check
-import lib.tags as M
-
 class test_escape:
 
     def t(self, s, expected):
@@ -63,8 +64,7 @@ class test_escape:
 
 def ast_to_tagnames(node):
     for child in ast.iter_child_nodes(node):
-        for t in ast_to_tagnames(child):
-            yield t
+        yield from ast_to_tagnames(child)
     ok = (
         isinstance(node, ast.Call) and
         isinstance(node.func, ast.Attribute) and
@@ -75,6 +75,7 @@ def ast_to_tagnames(node):
     if ok:
         yield node.args[0].s
 
+@collect_yielded
 def test_consistency():
     source_tagnames = set()
     def visit_mod(modname):
@@ -94,10 +95,10 @@ def test_consistency():
         if tag not in tagnames:
             raise AssertionError(
                 'tag missing in data/tags:\n\n'
-                '[{tag}]\n'
+                f'[{tag}]\n'
                 'severity = wishlist\n'
                 'certainty = wild-guess\n'
-                'description = TODO'.format(tag=tag)
+                'description = TODO'
             )
     for tag in sorted(source_tagnames | tagnames):
         yield test, tag
