@@ -1,4 +1,4 @@
-# Copyright © 2012-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -23,12 +23,12 @@ import os
 import pty
 import sys
 
-from nose.tools import (
+import lib.terminal as T
+
+from .tools import (
     assert_equal,
 )
 
-import lib.terminal as T
-
 from . import tools
 
 def test_strip_delay():
