@@ -1,4 +1,4 @@
-# Copyright © 2014 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2014-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -21,14 +21,14 @@
 import re
 import xml.etree.ElementTree as etree
 
-from nose.tools import (
+import lib.xml as M
+
+from .tools import (
     assert_is_none,
     assert_is_not_none,
     assert_raises,
 )
 
-import lib.xml as M
-
 class test_well_formed:
 
     def t(self, s):
@@ -68,7 +68,7 @@ class test_malformed:
         self.t(s)
 
 class test_name_re():
-    regexp = re.compile(r'\A{re}\Z'.format(re=M.name_re))
+    regexp = re.compile(fr'\A{M.name_re}\Z')
 
     def test_good(self):
         def t(s):
